# Noire

Noire is a Python module that provides programmatic access to Mailman via its
publicly-accessible web user interface.

Why the name "Noire"? This tool is meant to be a modern successor to
[`blanche`](https://debathena.mit.edu/manpages/www/manpages/lucid/man1/blanche.1.html),
but for Mailman. Noire is "black" in French, to contrast with "blanche"
(French for "white").

# License

MIT
